#!/bin/bash


# 判断/opt下是否存在12月版环境加域域名配置文件，存在则覆盖/etc下配置，并移除防火墙脚本。仅用于测试环境
if [ -e /opt/.kimserver.conf ]
then
  cp /opt/.kimserver.conf /etc
  iptable -F
  iptables -P OUTPUT ACCEPT
  iptables -P INPUT ACCEPT
  mv /opt/initial_firewall_220401.sh /opt/initial_firewall_220401.sh.bak
fi

# 获取加域域名
server_domain=$(cat /etc/.kimserver.conf | grep -o "^server.*" | awk -F" " '{print $3}')

log_file="/var/log/kylin-dz-config.log"
echo "启动脚本" >> $log_file
# 判断加域状态
domain_file="/etc/kim/default.conf"
if [ ! -e "$domain_file" ]
then
  echo "$(date "+%y%m%d %H:%M:%S")-当前终端未加域，不需要切换2.0环境" >> $log_file
  notify-send --app-name="安全管控升级工具" "当前终端未加域，不需要切换2.0环境"
  exit
else
  if [ `grep -c $server_domain /etc/kim/default.conf` -ne '0'  ]
  then
    echo "$(date "+%y%m%d %H:%M:%S")-当前终端已加域到2.0环境，不需要重新加域" >> $log_file
    notify-send --app-name="安全管控升级工具" "当前终端已加域到2.0环境，不需要重新加域"
    exit
  fi
fi

# 停止加域服务
systemctl stop kimdomain
systemctl restart hedron-domain-hook.service
# 重命名加域文件，以便重新加域
mv /etc/kim/default.conf /etc/kim/default.confbak


# 获取加域端口
dbus-send --system --print-reply --reply-timeout=60000 --type=method_call --dest=com.kylin.kim.domain / com.kylin.kim.domain.getDefaultServer >> $log_file



# 加域
count=0
echo "$(date "+%y%m%d %H:%M:%S")-开始加域，服务端域名$server_domain" >> $log_file
while [ 0 -eq 0 ]; do

  # 备份及替换初始策略文件
  if [ -e "/var/log/hedron/default-policy/default-policy.json" ]
  then
    cp /var/log/hedron/default-policy/default-policy.json /var/log/hedron/default-policy/default-policy.jsonbak
  fi
  sudo cp $resources_path/icbc/default-policy.json /var/log/hedron/default-policy/
  cp /var/log/hedron/policy_cache.json /var/log/hedron/policy_cache.jsonbak
  cp /var/log/hedron/default-policy/default-policy.json /var/log/hedron/policy_cache.json

  # 调用kim加域接口加域到11月版环境
  dbus-send --system --print-reply --reply-timeout=60000 --type=method_call --dest=com.kylin.kim.domain / com.kylin.kim.domain.deviceSNJoin string:$server_domain >> $log_file

  # 根据default.conf文件判断加域是否成功
  if [ -e "$domain_file" ]
  then
    flag=0
  else
    flag=1
  fi

  # 失败重试3次
  if [[ $flag -eq 0 ]]
  then
    echo "$(date "+%y%m%d %H:%M:%S")-加域成功" >> $log_file
    notify-send --app-name="安全管控升级工具" "安全管控客户端升级成功"
    break
  else
    count=$[${count}+1]
    if [[ ${count} -eq 4 ]]
    then
      echo "$(date "+%y%m%d %H:%M:%S")-加域失败，请联系管理员" >> $log_file
      notify-send --app-name="安全管控升级工具" "安全管控客户端加域失败，请联系管理员"
      # 失败则还原配置文件
      mv /etc/kim/default.confbak /etc/kim/default.conf
      if [ -e "/var/log/hedron/default-policy/default-policy.json" ]
      then
        mv /var/log/hedron/default-policy/default-policy.jsonbak /var/log/hedron/default-policy/default-policy.json
      fi
      mv /var/log/hedron/policy_cache.jsonbak /var/log/hedron/policy_cache.json
      break
    fi
    echo "$(date "+%y%m%d %H:%M:%S")-第${count}次重试加域" >> $log_file
    sleep 3
  fi
done

# 加域失败终止脚本
if [[ $flag -eq 1 ]]
then
  exit
fi


# 修改家目录属主（域用户名跟主机名一致）
username=$(echo _$hostname | awk -F"." '{printf $1}' | awk -F"-" '{printf $1}' | tr -d 'a-z')
chown -R $username /home/$username
if [[ $? != 0 ]]
then
  echo "$(date "+%y%m%d %H:%M:%S")-修改家目录属主失败，请联系管理员" >> $log_file
  notify-send --app-name="安全管控升级工具" "修改家目录属主失败，请联系管理员"
else
  echo "$(date "+%y%m%d %H:%M:%S")-修改家目录属主成功" >> $log_file
fi

notify-send --app-name="安全管控升级工具" "20秒后终端将重启以完成安全管控客户端升级"
sleep 20
# 重启终端
reboot
if [[ $? != 0 ]]
then
  echo "$(date "+%y%m%d %H:%M:%S")-重启失败"  >> $log_file
  notify-send --app-name="安全管控升级工具" "重启失败，请手动重启以完成升级"
fi